package nl.xelion.xcc.api.examples.client;

import java.io.IOException;

import nl.xelion.xcc.api.examples.client.datamodel.LoginCredentials;

/**
 * Xelion Client that logins to the server, fetches the server capabilities and logouts.
 * <p>
 * This software is provided under the MIT <a href="https://opensource.org/licenses/MIT">license</a>
 */
public class Client
{
    private static final String USAGE = "Program arguments: -u user -p password -h host";

    public Client(String user, String password, String host) throws IOException, RequestException
    {
        //
        // start session
        LoginCredentials credentials = new LoginCredentials(user, password, "xelion client");
        Response<Session> response = Session.login(credentials, host, null);
        System.out.println("\n\tlogin -> " + response);

        if (response.success())
        {
            Session session = response.value();

            //
            // check session capabilities
            System.out.println("\n\tcapabilities -> " + session.request(Resources.capabilities.get()));

            //
            // close session
            session.request(Resources.logout.exec()).applyToError(r -> System.out.println("logout -> " + r));
            System.out.println("\n\tlogout -> Session closed");
        }
    }

    public static void main(String[] args)
    {
        String user = null, password = null, host = null;
        if (args.length < 6)
            printUsageAndExit();

        for (int i = 0; i < 5; i = i + 2)
        {
            String arg = args[i];
            String val = args[i + 1];
            if ("-u".equals(arg))
                user = val;
            else if ("-p".equals(arg))
                password = val;
            else if ("-h".equals(arg))
                host = val;
            else
                printUsageAndExit();
        }

        if (user == null || password == null || host == null)
            printUsageAndExit();

        try
        {
            new Client(user, password, host);
        }
        catch (IOException | RequestException e)
        {
            System.err.println("Error: " + e);
        }
    }

    private static void printUsageAndExit()
    {
        System.err.println(USAGE);
        System.exit(1);
    }
}
