package nl.xelion.xcc.api.examples.client.datamodel;

import java.util.List;

/**
 * A response object wraps a value of a resource. This object is returned by resource requests that generate a single
 * value.
 * <p>
 * In addition to the wrapped value, this object contains a list of HATEOAS links.
 * <p>
 * This software is provided under the MIT <a href="https://opensource.org/licenses/MIT">license</a>
 */
public class RESTObject<T>
{
    /**
     * The resource value.
     */
    private T object;

    /**
     * HATEOAS links of the object.
     */
    private List<HATEOASLink> links;

    public RESTObject()
    {
        // empty constructor for GSON
    }

    public RESTObject(T object, List<HATEOASLink> links)
    {
        this.object = object;
        this.links = links;
    }

    /**
     * @return the object
     */
    public T getObject()
    {
        return object;
    }

    /**
     * @return the links
     */
    public List<HATEOASLink> getLinks()
    {
        return links;
    }

    @Override
    public String toString()
    {
        return "[object=" + object + ", links=" + links + "]";
    }
}
