package nl.xelion.xcc.api.examples.client.http;

import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import com.google.gson.Gson;

import nl.xelion.xcc.api.examples.client.http.HTTPConstants.HTTPHeader;
import nl.xelion.xcc.api.examples.client.http.HTTPConstants.HTTPMethod;
import nl.xelion.xcc.api.examples.client.http.HTTPConstants.MediaType;

/**
 * A builder for an {@link HTTPRequest}
 * <p>
 * This software is provided under the MIT <a href="https://opensource.org/licenses/MIT">license</a>
 */
public class HTTPRequestBuilder
{
    private String url;
    private HTTPMethod method = HTTPMethod.GET;
    private Map<String, String> headers = new HashMap<>();
    private byte[] content;

    public HTTPRequestBuilder(String url)
    {
        this.url = Objects.requireNonNull(url);
    }

    public HTTPRequest build()
    {
        return new HTTPRequest(url, method, content, headers);
    }

    public HTTPRequestBuilder setMethod(HTTPMethod method)
    {
        this.method = Objects.requireNonNull(method);
        return this;
    }

    public HTTPRequestBuilder setHeader(String name, String value)
    {
        headers.put(name, value);
        return this;
    }

    public HTTPRequestBuilder setContent(byte[] content)
    {
        this.content = content;
        return this;
    }

    public HTTPRequestBuilder setContent(String content_string)
    {
        if (content_string == null)
        {
            this.content = null;
        }
        else
        {
            this.content = content_string.getBytes(StandardCharsets.UTF_8);
        }
        return this;
    }

    public HTTPRequestBuilder setJSONContent(Object object)
    {
        Objects.requireNonNull(object);
        setContent(new Gson().toJson(object));
        return setHeader(HTTPHeader.ContentType, MediaType.ApplicationJSON);
    }

    @Override
    public String toString()
    {
        return "HTTPRequestBuilder [url="
            + url
            + ", method="
            + method
            + ", headers="
            + headers
            + ", content-size="
            + (content == null ? 0 : content.length)
            + "]";
    }
}
