package nl.xelion.xcc.api.examples.client.http;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.Objects;

/**
 * The query part of an URL.
 * <p>
 * This software is provided under the MIT <a href="https://opensource.org/licenses/MIT">license</a>
 */
public class URLQuery
{
    private final String query;

    private URLQuery(String query)
    {
        this.query = query;
    }

    public static URLQuery of(String name)
    {
        return of(name, null);
    }

    public static URLQuery of(String name, String value)
    {
        return new URLQuery(encode(name, value));
    }

    public URLQuery add(String name)
    {
        return add(name, null);
    }

    public URLQuery add(String name, String value)
    {
        return new URLQuery(query + "&" + encode(name, value));
    }

    @Override
    public String toString()
    {
        return query;
    }

    private static String encode(String name, String value)
    {
        String s = encode(Objects.requireNonNull(name));
        return value == null ? s : s + "=" + encode(value);
    }

    private static String encode(String s)
    {
        try
        {
            return URLEncoder.encode(s, StandardCharsets.UTF_8.name());
        }
        catch (UnsupportedEncodingException e)
        {
            return s; // won't happen
        }
    }
}
